==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-directorymenu/translations/directorymenu_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Öppna i terminal</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Inställningar för mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Basmapp:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>BaseDirectoryName</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Välj standard Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Välj basmapp</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Välj ikon</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Ett fel inträffade när ikonen laddades.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-directorymenu/translations/directorymenu_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Öppna</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Öppna i terminal</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Inställningar för mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Basmapp:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>BaseDirectoryName</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation>Etikett</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation>Knappstil</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Välj standard Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation>Endast ikon</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation>Endast text</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation>Ikon och text</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Välj basmapp</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Välj ikon</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation>Ikoner (*.png *.xpm *.jpg *.svg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation>Välj etikett</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation>Etikett:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Mapp-meny</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Ett fel inträffade när ikonen laddades.</translation>
    </message>
</context>
</TS>
